==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S397a0b3c66c6263bdff69678c0b45a68.c <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!




















































#include "Sd7da8ed8a8cac9d030adbcb140ee38b6.h"

#include "S397a0b3c66c6263bdff69678c0b45a68.h"

#include <netdb.h>
 const int Sbb1bd8eaa4bcf7d3e7ac91902bd0f280 = 50; S7fff041b8d86bb55dda5d573157f7916 * Sf9f65dfb16c17227235af67eab8e522c(S21714a766410d0271630454c797af94c* 
S28dd376c5a44acc92e450ee338260c56, unsigned long S0d9e966c432e9d663b41e1ae16fd4232) { int S9c3c41e7b10210b1e6a9d96d917d6dd7; 
unsigned char *S30dcf3a5bcc8368556e53e604d104151 = NULL; unsigned char *S69a4dd36dd15518abff187a41b67b64c 
= NULL; S7fff041b8d86bb55dda5d573157f7916 * Sde17f0f24b49f8364187891f8550ffbb; int Seedf5beb047f6e2c46b7d59343581aaf 
= 0; int S363b122c528f54df4a0446b6bab05515, S6baa7521a39aed1d69687066769d1cec; double S28c1e37e317b935a387dbe232bc9f803 
= 0, Sba569b80f7bb7762f073f1be57cc36aa = 0; Sde17f0f24b49f8364187891f8550ffbb = malloc(sizeof(S7fff041b8d86bb55dda5d573157f7916)); 
memset(Sde17f0f24b49f8364187891f8550ffbb, 0, sizeof(S7fff041b8d86bb55dda5d573157f7916)); S6baa7521a39aed1d69687066769d1cec 
= Sf67969905b27803500953d9068aecf78(S28dd376c5a44acc92e450ee338260c56, S0d9e966c432e9d663b41e1ae16fd4232); 
if (S6baa7521a39aed1d69687066769d1cec == S28dd376c5a44acc92e450ee338260c56->Sea0f67beb9aa4ed6106b3566e1cfa2d7[0]) 
return NULL; S9c3c41e7b10210b1e6a9d96d917d6dd7 = S6baa7521a39aed1d69687066769d1cec + (2 * Sa3b40c8a1cab91f00046e3a3cc950376 
- 1) * S28dd376c5a44acc92e450ee338260c56->Sea0f67beb9aa4ed6106b3566e1cfa2d7[0]; if (S28dd376c5a44acc92e450ee338260c56->S0fea6a13c52b4d4725368f24b045ca84 
== NULL) { fseek(S28dd376c5a44acc92e450ee338260c56->S516bd74e9031c906e09afa026fb1b736, S9c3c41e7b10210b1e6a9d96d917d6dd7, 
SEEK_SET); S69a4dd36dd15518abff187a41b67b64c = S30dcf3a5bcc8368556e53e604d104151 = malloc(sizeof(char) 
* Sbb1bd8eaa4bcf7d3e7ac91902bd0f280); fread(S30dcf3a5bcc8368556e53e604d104151, sizeof(char), Sbb1bd8eaa4bcf7d3e7ac91902bd0f280, 
S28dd376c5a44acc92e450ee338260c56->S516bd74e9031c906e09afa026fb1b736); } else { S30dcf3a5bcc8368556e53e604d104151 
= S28dd376c5a44acc92e450ee338260c56->S0fea6a13c52b4d4725368f24b045ca84 + (long)S9c3c41e7b10210b1e6a9d96d917d6dd7; 
}  Sde17f0f24b49f8364187891f8550ffbb->S55eceb8dde5fdfa0e4bfa50de80513e2 = (char *) S35dea755991b8d1c5d6d0a81372a5667 
[S30dcf3a5bcc8368556e53e604d104151[0]]; Sde17f0f24b49f8364187891f8550ffbb->S9509726fdc6049e44ad11ec91fb81356 
= (char *) Sa2006be4dc95ac0acfcc6e0d777c72ce[S30dcf3a5bcc8368556e53e604d104151[0]]; Sde17f0f24b49f8364187891f8550ffbb->Sb8ada0d76480a14072b34559449fb532 
= (char *) S3fa47b9862302484684bb50bea85dd54 [S30dcf3a5bcc8368556e53e604d104151[0]]; S30dcf3a5bcc8368556e53e604d104151++; 
 while (S30dcf3a5bcc8368556e53e604d104151[Seedf5beb047f6e2c46b7d59343581aaf] != '\0') Seedf5beb047f6e2c46b7d59343581aaf++; 
if (Seedf5beb047f6e2c46b7d59343581aaf > 0) { Sde17f0f24b49f8364187891f8550ffbb->S960db2ed82202a9706b97775a4269378 
= malloc(Seedf5beb047f6e2c46b7d59343581aaf+1); strncpy(Sde17f0f24b49f8364187891f8550ffbb->S960db2ed82202a9706b97775a4269378, 
S30dcf3a5bcc8368556e53e604d104151, Seedf5beb047f6e2c46b7d59343581aaf+1); } S30dcf3a5bcc8368556e53e604d104151 
+= Seedf5beb047f6e2c46b7d59343581aaf + 1; Seedf5beb047f6e2c46b7d59343581aaf = 0;  while (S30dcf3a5bcc8368556e53e604d104151[Seedf5beb047f6e2c46b7d59343581aaf] 
!= '\0') Seedf5beb047f6e2c46b7d59343581aaf++; if (Seedf5beb047f6e2c46b7d59343581aaf > 0) { Sde17f0f24b49f8364187891f8550ffbb->S4ed5d2eaed1a1fadcc41ad1d58ed603e 
= malloc(Seedf5beb047f6e2c46b7d59343581aaf+1); strncpy(Sde17f0f24b49f8364187891f8550ffbb->S4ed5d2eaed1a1fadcc41ad1d58ed603e, 
S30dcf3a5bcc8368556e53e604d104151, Seedf5beb047f6e2c46b7d59343581aaf+1); } S30dcf3a5bcc8368556e53e604d104151 
+= (Seedf5beb047f6e2c46b7d59343581aaf + 1);  for (S363b122c528f54df4a0446b6bab05515 = 0; S363b122c528f54df4a0446b6bab05515 
< 3; S363b122c528f54df4a0446b6bab05515++) S28c1e37e317b935a387dbe232bc9f803 += (S30dcf3a5bcc8368556e53e604d104151[S363b122c528f54df4a0446b6bab05515] 
<< (S363b122c528f54df4a0446b6bab05515 * 8)); Sde17f0f24b49f8364187891f8550ffbb->S28c1e37e317b935a387dbe232bc9f803 
= S28c1e37e317b935a387dbe232bc9f803/10000 - 180; S30dcf3a5bcc8368556e53e604d104151 += 3;  for (S363b122c528f54df4a0446b6bab05515 
= 0; S363b122c528f54df4a0446b6bab05515 < 3; S363b122c528f54df4a0446b6bab05515++) Sba569b80f7bb7762f073f1be57cc36aa 
+= (S30dcf3a5bcc8368556e53e604d104151[S363b122c528f54df4a0446b6bab05515] << (S363b122c528f54df4a0446b6bab05515 
* 8)); Sde17f0f24b49f8364187891f8550ffbb->Sba569b80f7bb7762f073f1be57cc36aa = Sba569b80f7bb7762f073f1be57cc36aa/10000 
- 180; if (S28dd376c5a44acc92e450ee338260c56->S0fea6a13c52b4d4725368f24b045ca84 == NULL) free(S69a4dd36dd15518abff187a41b67b64c); 
return Sde17f0f24b49f8364187891f8550ffbb; } S7fff041b8d86bb55dda5d573157f7916 * Sec62f5595b8d619f94d47d73a87f1880 
(S21714a766410d0271630454c797af94c* S28dd376c5a44acc92e450ee338260c56, const char *S3ef9a0d7fab5d2bcabf0978c0a35244e) 
{ unsigned long S0d9e966c432e9d663b41e1ae16fd4232; if (S3ef9a0d7fab5d2bcabf0978c0a35244e == NULL) { 
return 0; } S0d9e966c432e9d663b41e1ae16fd4232 = S5523403a284caa5fa8302aba7090a4c8(S3ef9a0d7fab5d2bcabf0978c0a35244e); 
return Sf9f65dfb16c17227235af67eab8e522c(S28dd376c5a44acc92e450ee338260c56, S0d9e966c432e9d663b41e1ae16fd4232); 
} S7fff041b8d86bb55dda5d573157f7916 * Sb54383ef62fb8247300fb3c8be0ed4b0 (S21714a766410d0271630454c797af94c* 
S28dd376c5a44acc92e450ee338260c56, const char *Sb068931cc450442b63f5b3d276ea4297) { unsigned long S0d9e966c432e9d663b41e1ae16fd4232; 
struct hostent * S67b3dba8bc6778101892eb77249db32e; if (Sb068931cc450442b63f5b3d276ea4297 == NULL) { 
return 0; } S0d9e966c432e9d663b41e1ae16fd4232 = S5523403a284caa5fa8302aba7090a4c8(Sb068931cc450442b63f5b3d276ea4297); 
if (S0d9e966c432e9d663b41e1ae16fd4232 == 0) { S67b3dba8bc6778101892eb77249db32e = gethostbyname(Sb068931cc450442b63f5b3d276ea4297); 
if (S67b3dba8bc6778101892eb77249db32e == NULL) { return 0; } S0d9e966c432e9d663b41e1ae16fd4232 = Sde5a212cfcd52ab5f622d13eed574c29((unsigned 
char *) S67b3dba8bc6778101892eb77249db32e->h_addr_list[0]); } return Sf9f65dfb16c17227235af67eab8e522c(S28dd376c5a44acc92e450ee338260c56, 
S0d9e966c432e9d663b41e1ae16fd4232); } void Sc73f9c3b44a6ef4e844b6d82a086bb70 (S7fff041b8d86bb55dda5d573157f7916 
*Se589d341207cfa0210eb13e751b4656a) { free(Se589d341207cfa0210eb13e751b4656a->S960db2ed82202a9706b97775a4269378); 
free(Se589d341207cfa0210eb13e751b4656a->S4ed5d2eaed1a1fadcc41ad1d58ed603e); free(Se589d341207cfa0210eb13e751b4656a); 
}

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S397a0b3c66c6263bdff69678c0b45a68.c <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!




















































#include "Sd7da8ed8a8cac9d030adbcb140ee38b6.h"

#include "S397a0b3c66c6263bdff69678c0b45a68.h"
 const int Sbb1bd8eaa4bcf7d3e7ac91902bd0f280 = 50; S7fff041b8d86bb55dda5d573157f7916 * Sf9f65dfb16c17227235af67eab8e522c(S21714a766410d0271630454c797af94c* 
S28dd376c5a44acc92e450ee338260c56, unsigned long S0d9e966c432e9d663b41e1ae16fd4232) { int S9c3c41e7b10210b1e6a9d96d917d6dd7; 
unsigned char *S30dcf3a5bcc8368556e53e604d104151 = NULL; unsigned char *S69a4dd36dd15518abff187a41b67b64c 
= NULL; S7fff041b8d86bb55dda5d573157f7916 * Sde17f0f24b49f8364187891f8550ffbb; int Seedf5beb047f6e2c46b7d59343581aaf 
= 0; int S363b122c528f54df4a0446b6bab05515, S6baa7521a39aed1d69687066769d1cec; double S28c1e37e317b935a387dbe232bc9f803 
= 0, Sba569b80f7bb7762f073f1be57cc36aa = 0; Sde17f0f24b49f8364187891f8550ffbb = malloc(sizeof(S7fff041b8d86bb55dda5d573157f7916)); 
memset(Sde17f0f24b49f8364187891f8550ffbb, 0, sizeof(S7fff041b8d86bb55dda5d573157f7916)); S6baa7521a39aed1d69687066769d1cec 
= Sf67969905b27803500953d9068aecf78(S28dd376c5a44acc92e450ee338260c56, S0d9e966c432e9d663b41e1ae16fd4232); 
if (S6baa7521a39aed1d69687066769d1cec == S28dd376c5a44acc92e450ee338260c56->Sea0f67beb9aa4ed6106b3566e1cfa2d7[0]) 
return NULL; S9c3c41e7b10210b1e6a9d96d917d6dd7 = S6baa7521a39aed1d69687066769d1cec + (2 * Sa3b40c8a1cab91f00046e3a3cc950376 
- 1) * S28dd376c5a44acc92e450ee338260c56->Sea0f67beb9aa4ed6106b3566e1cfa2d7[0]; if (S28dd376c5a44acc92e450ee338260c56->S0fea6a13c52b4d4725368f24b045ca84 
== NULL) { fseek(S28dd376c5a44acc92e450ee338260c56->S516bd74e9031c906e09afa026fb1b736, S9c3c41e7b10210b1e6a9d96d917d6dd7, 
SEEK_SET); S69a4dd36dd15518abff187a41b67b64c = S30dcf3a5bcc8368556e53e604d104151 = malloc(sizeof(char) 
* Sbb1bd8eaa4bcf7d3e7ac91902bd0f280); fread(S30dcf3a5bcc8368556e53e604d104151, sizeof(char), Sbb1bd8eaa4bcf7d3e7ac91902bd0f280, 
S28dd376c5a44acc92e450ee338260c56->S516bd74e9031c906e09afa026fb1b736); } else { S30dcf3a5bcc8368556e53e604d104151 
= S28dd376c5a44acc92e450ee338260c56->S0fea6a13c52b4d4725368f24b045ca84 + (long)S9c3c41e7b10210b1e6a9d96d917d6dd7; 
}  Sde17f0f24b49f8364187891f8550ffbb->S55eceb8dde5fdfa0e4bfa50de80513e2 = (char *) S35dea755991b8d1c5d6d0a81372a5667 
[S30dcf3a5bcc8368556e53e604d104151[0]]; Sde17f0f24b49f8364187891f8550ffbb->S9509726fdc6049e44ad11ec91fb81356 
= (char *) Sa2006be4dc95ac0acfcc6e0d777c72ce[S30dcf3a5bcc8368556e53e604d104151[0]]; Sde17f0f24b49f8364187891f8550ffbb->Sb8ada0d76480a14072b34559449fb532 
= (char *) S3fa47b9862302484684bb50bea85dd54 [S30dcf3a5bcc8368556e53e604d104151[0]]; S30dcf3a5bcc8368556e53e604d104151++; 
 while (S30dcf3a5bcc8368556e53e604d104151[Seedf5beb047f6e2c46b7d59343581aaf] != '\0') Seedf5beb047f6e2c46b7d59343581aaf++; 
if (Seedf5beb047f6e2c46b7d59343581aaf > 0) { Sde17f0f24b49f8364187891f8550ffbb->S960db2ed82202a9706b97775a4269378 
= malloc(Seedf5beb047f6e2c46b7d59343581aaf+1); strncpy(Sde17f0f24b49f8364187891f8550ffbb->S960db2ed82202a9706b97775a4269378, 
S30dcf3a5bcc8368556e53e604d104151, Seedf5beb047f6e2c46b7d59343581aaf+1); } S30dcf3a5bcc8368556e53e604d104151 
+= Seedf5beb047f6e2c46b7d59343581aaf + 1; Seedf5beb047f6e2c46b7d59343581aaf = 0;  while (S30dcf3a5bcc8368556e53e604d104151[Seedf5beb047f6e2c46b7d59343581aaf] 
!= '\0') Seedf5beb047f6e2c46b7d59343581aaf++; if (Seedf5beb047f6e2c46b7d59343581aaf > 0) { Sde17f0f24b49f8364187891f8550ffbb->S4ed5d2eaed1a1fadcc41ad1d58ed603e 
= malloc(Seedf5beb047f6e2c46b7d59343581aaf+1); strncpy(Sde17f0f24b49f8364187891f8550ffbb->S4ed5d2eaed1a1fadcc41ad1d58ed603e, 
S30dcf3a5bcc8368556e53e604d104151, Seedf5beb047f6e2c46b7d59343581aaf+1); } S30dcf3a5bcc8368556e53e604d104151 
+= (Seedf5beb047f6e2c46b7d59343581aaf + 1);  for (S363b122c528f54df4a0446b6bab05515 = 0; S363b122c528f54df4a0446b6bab05515 
< 3; S363b122c528f54df4a0446b6bab05515++) S28c1e37e317b935a387dbe232bc9f803 += (S30dcf3a5bcc8368556e53e604d104151[S363b122c528f54df4a0446b6bab05515] 
<< (S363b122c528f54df4a0446b6bab05515 * 8)); Sde17f0f24b49f8364187891f8550ffbb->S28c1e37e317b935a387dbe232bc9f803 
= S28c1e37e317b935a387dbe232bc9f803/10000 - 180; S30dcf3a5bcc8368556e53e604d104151 += 3;  for (S363b122c528f54df4a0446b6bab05515 
= 0; S363b122c528f54df4a0446b6bab05515 < 3; S363b122c528f54df4a0446b6bab05515++) Sba569b80f7bb7762f073f1be57cc36aa 
+= (S30dcf3a5bcc8368556e53e604d104151[S363b122c528f54df4a0446b6bab05515] << (S363b122c528f54df4a0446b6bab05515 
* 8)); Sde17f0f24b49f8364187891f8550ffbb->Sba569b80f7bb7762f073f1be57cc36aa = Sba569b80f7bb7762f073f1be57cc36aa/10000 
- 180; if (S28dd376c5a44acc92e450ee338260c56->S0fea6a13c52b4d4725368f24b045ca84 == NULL) free(S69a4dd36dd15518abff187a41b67b64c); 
return Sde17f0f24b49f8364187891f8550ffbb; } S7fff041b8d86bb55dda5d573157f7916 * Sec62f5595b8d619f94d47d73a87f1880 
(S21714a766410d0271630454c797af94c* S28dd376c5a44acc92e450ee338260c56, const char *S3ef9a0d7fab5d2bcabf0978c0a35244e) 
{ unsigned long S0d9e966c432e9d663b41e1ae16fd4232; if (S3ef9a0d7fab5d2bcabf0978c0a35244e == NULL) { 
return 0; } S0d9e966c432e9d663b41e1ae16fd4232 = S5523403a284caa5fa8302aba7090a4c8(S3ef9a0d7fab5d2bcabf0978c0a35244e); 
return Sf9f65dfb16c17227235af67eab8e522c(S28dd376c5a44acc92e450ee338260c56, S0d9e966c432e9d663b41e1ae16fd4232); 
} S7fff041b8d86bb55dda5d573157f7916 * Sb54383ef62fb8247300fb3c8be0ed4b0 (S21714a766410d0271630454c797af94c* 
S28dd376c5a44acc92e450ee338260c56, const char *Sb068931cc450442b63f5b3d276ea4297) { unsigned long S0d9e966c432e9d663b41e1ae16fd4232; 
struct hostent * S67b3dba8bc6778101892eb77249db32e; if (Sb068931cc450442b63f5b3d276ea4297 == NULL) { 
return 0; } S0d9e966c432e9d663b41e1ae16fd4232 = S5523403a284caa5fa8302aba7090a4c8(Sb068931cc450442b63f5b3d276ea4297); 
if (S0d9e966c432e9d663b41e1ae16fd4232 == 0) { 
#if 0
 S67b3dba8bc6778101892eb77249db32e = gethostbyname(Sb068931cc450442b63f5b3d276ea4297); if (S67b3dba8bc6778101892eb77249db32e 
== NULL) { return 0; } S0d9e966c432e9d663b41e1ae16fd4232 = Sde5a212cfcd52ab5f622d13eed574c29((unsigned 
char *) S67b3dba8bc6778101892eb77249db32e->h_addr_list[0]); 
#endif
 } return Sf9f65dfb16c17227235af67eab8e522c(S28dd376c5a44acc92e450ee338260c56, S0d9e966c432e9d663b41e1ae16fd4232); 
} void Sc73f9c3b44a6ef4e844b6d82a086bb70 (S7fff041b8d86bb55dda5d573157f7916 *Se589d341207cfa0210eb13e751b4656a) 
{ free(Se589d341207cfa0210eb13e751b4656a->S960db2ed82202a9706b97775a4269378); free(Se589d341207cfa0210eb13e751b4656a->S4ed5d2eaed1a1fadcc41ad1d58ed603e); 
free(Se589d341207cfa0210eb13e751b4656a); }
